<!-- DOC_TYPE: API -->

# Core Internal Modules

These modules back the public `core` helpers and expose the implementation-level docstrings for context processors, mixins, selectors, and Redis integration.

## Context processors

::: codex_django.core.context_processors

## Model mixins

::: codex_django.core.mixins.models

## Sitemaps

::: codex_django.core.sitemaps

## SEO selectors

::: codex_django.core.seo.selectors

## i18n discovery

::: codex_django.core.i18n.discovery

## Translation command

::: codex_django.core.management.commands.codex_makemessages

## Template tags

::: codex_django.core.templatetags.codex_i18n

## Redis base manager

::: codex_django.core.redis.managers.base

## Redis settings manager

::: codex_django.core.redis.managers.settings

## Redis SEO manager

::: codex_django.core.redis.managers.seo

## Redis notifications manager

::: codex_django.core.redis.managers.notifications

## Redis booking manager

::: codex_django.core.redis.managers.booking
